@@ -2,4 +2,6 @@
 Overview:
     Testing process module, include some useful utilities for unittest.
 """
+from .capture import *
 from .generator import *
+from .isolated import *
